@@ -12,9 +12,12 @@ use std::collections::HashMap;
 
 pub(crate) use error::IResult;
 
-use crate::compiler::{
-	Command,
-	Segment,
+use crate::{
+	compiler::{
+		Command,
+		Segment,
+	},
+	Args,
 };
 macro_rules! err {
 	() => {{
@@ -25,37 +28,10 @@ pub(crate) use err;
 
 #[derive(Eq, PartialEq, Clone, Debug)]
 pub enum Match<'a> {
-	None,
 	Once(&'a str),
 	Many(Vec<&'a str>),
 }
 
-impl<'a> Match<'a> {
-	pub fn is_none(&self) -> bool {
-		self == &Self::None
-	}
-}
-
-#[derive(PartialEq, Eq, Clone)]
-pub struct Args<'c, 't> {
-	pub(crate) rest: &'t str,
-	pub(crate) vals: HashMap<&'c str, Match<'t>>,
-}
-
-impl<'c, 't> Args<'c, 't> {
-	pub fn get<'z: 't + 'c>(&'z self, name: &str) -> &'z Match<'z> {
-		self.vals.get(name).unwrap_or(&Match::None)
-	}
-
-	pub fn rest(&'c self) -> Option<&'t str> {
-		if self.rest.is_empty() {
-			None
-		} else {
-			Some(self.rest)
-		}
-	}
-}
-
 impl<'c, 't> Command {
 	pub fn get_matches(&'c self, s: &'t str) -> Option<Args<'c, 't>> {
 		if self.0.is_empty() {
@@ -75,7 +51,7 @@ impl<'c, 't> Command {
 					// No limitations on the amount of matches.
 					let (new_rem, matches) = c.get_match(remaining, |_| true).ok()?;
 					remaining = new_rem;
-					if !matches.is_none() {
+					if let Some(matches) = matches {
 						vals.insert(c.name.as_str(), matches);
 					}
 				}
@@ -85,7 +61,7 @@ impl<'c, 't> Command {
 					let good = move |s: &str| -> bool { !next.is_match(s) };
 					let (new_rem, matches) = c.get_match(remaining, good).ok()?;
 					remaining = new_rem;
-					if !matches.is_none() {
+					if let Some(matches) = matches {
 						vals.insert(c.name.as_str(), matches);
 					}
 				}
